from repo_core.domains.telegram.telegram_parsed_message.model import (
    TelegramParsedMessage,
    MessageDetail,
    MessageReaction,
)
from repo_core.domains.telegram.telegram_parsed_message.repository import (
    TelegramParsedMessageRepository,
    MessageDetailRepository,
    MessageReactionRepository,
)
