"""PipelineErrorRepository — Doris-backed repository for pipeline errors."""

from __future__ import annotations

from typing import Any

from repo_core.base import BaseRepository

from .model import PipelineError


class PipelineErrorRepository(BaseRepository[PipelineError]):
    """Repository for pipeline_errors — Doris warehouse only.

    Errors are written directly to the warehouse (not PostgreSQL or
    Elasticsearch) so they are available for dashboard queries.
    """

    _backends = {"doris"}

    TABLE = "pipeline_errors"
